@@ -30,7 +30,7 @@ class Config(object):
     SERIES = 'series'
 
     ALL = '*'
-    DEFAULT_QUEUED = 'Q'  # TODO: should this be a CLI option?
+    DEFAULT_QUEUED = 'Queued'  # TODO: should this be a CLI option?
 
     BRANCHES = 'branches'
     REBUILD = 'rebuild'
@@ -65,6 +65,7 @@ class Config(object):
         """
         logging.debug("parsing config {0}...".format(path))
         cfg = ConfigParser.RawConfigParser()
+        cfg.optionxform = str  # preserve case in options
         cfg.read(path)
         section = TRACKING
         if cfg.has_section(section):
@@ -88,7 +89,7 @@ class Config(object):
             if cfg.has_section(section):
                 for option, value in cfg.items(section):
                     alias, setting = option.split('_')
-                    self.config[section][alias.upper()][setting] = value  # TODO: is upper required?
+                    self.config[section][alias][setting] = value
         self.display()
         self.updated = True
 
@@ -129,7 +130,7 @@ class Config(object):
 
     @property
     def enters(self):
-        """Get a list of entry state aliases.
+        """Get a list of entry status aliases.
         """
         aliases = []
         for data in self.config[BUILDER].itervalues():
@@ -140,7 +141,7 @@ class Config(object):
 
     @property
     def exits(self):
-        """Get a list of exit and fail state aliases.
+        """Get a list of exit and fail status aliases.
         """
         aliases = []
         for data in self.config[BUILDER].itervalues():
@@ -151,7 +152,7 @@ class Config(object):
 
     @property
     def fails(self):
-        """Get a list of fail state aliases.
+        """Get a list of fail status aliases.
         """
         aliases = []
         for data in self.config[BUILDER].itervalues():
@@ -162,20 +163,20 @@ class Config(object):
 
     @property
     def starts(self):
-        """Get a list of all initial state aliases.
+        """Get a list of all initial status aliases.
         """
         return [alias for alias in self.enters if alias not in self.exits] or [Config.DEFAULT_QUEUED]
 
     @property
     def ends(self):
-        """Get a list of all final state aliases.
+        """Get a list of all final status aliases.
         """
         return [alias for alias in self.exits if alias not in self.enters]
 
     def next(self, status):
-        """Get the next build state alias.
-        @param status: current state alias
-        @return: next state alias
+        """Get the next build status alias.
+        @param status: current status alias
+        @return: next status alias
         """
         logging.debug("entering next state from [{0}]...".format(status))
         for alias, data in self.config[BUILDER].iteritems():
@@ -185,9 +186,9 @@ class Config(object):
         raise ValueError("no state to enter from [{0}]".format(status))
 
     def fail(self, status):
-        """Get the build state alias for a failure.
-        @param status: current state alias
-        @return: failed state alias
+        """Get the build status alias for a failure.
+        @param status: current status alias
+        @return: failed status alias
         """
         logging.debug("failing from build state [{0}]...".format(status))
         alias = self.config[BUILDER][status][Config.FAIL]
@@ -198,9 +199,9 @@ class Config(object):
             raise ValueError("no state to fail from [{0}]".format(status))
 
     def exit(self, status):
-        """Get the build state alias for success.
-        @param status: current state alias
-        @return: passed state alias
+        """Get the build status alias for success.
+        @param status: current status alias
+        @return: passed status alias
         """
         logging.debug("exiting from build state [{0}]...".format(status))
         alias = self.config[BUILDER][status][Config.EXIT]
@@ -240,7 +241,7 @@ class Config(object):
 
     def get_build(self, status):
         """Get the items to perform a build operation.
-        @param status: current state alias
+        @param status: current status alias
         @return: path, command
         """
         logging.debug("getting build operations for state [{0}]...".format(status))
