@@ -591,7 +591,10 @@ class Repository(_Base):
         """
         logging.info("requesting [{s}] build of '{c}' for [{e}] in '{r}'...".format(s=series, e=environment,
                                                                                     c=cid, r=self))
-        args = [name, series, environment, status, cid] + ([branch] if branch else [])
+        if branch:
+            args = name, series, environment, status, cid, branch
+        else:
+            args = name, series, environment, status, cid
         bid, cid, _name, _series, _environment = next(vscript.parse(vscript.report_build(self, 'new', *args),
                                                                     style='builds'))
         return BuildRequest(bid, cid, name=name, series=series, environment=environment,
@@ -638,9 +641,9 @@ class Repository(_Base):
         """
         logging.debug("getting all build requests in '{r}'...".format(r=self))
         if limit:
-            args = self, 'list', 'null', 'null', limit
+            args = self, 'list', 'null', 'started#DESC', limit
         else:
-            args = self, 'list'
+            args = self, 'list', 'null', 'started#DESC'
         for bid, cid, name, series, environment in vscript.parse(vscript.report_build(*args), style='builds'):
             request = BuildRequest(bid, cid, name=name, series=series, environment=environment, repo=self)
             logging.debug("build request: {0}".format(request))
