@@ -47,6 +47,11 @@ class Poller(_BaseRepositoryObject):
     def __ne__(self, other):
         return not self == other
 
+    def sync(self):
+        """Synchronize local and remote repositories.
+        """
+        self.repo.sync()
+
     def run(self):
         """Perform one poll iteration.
         """
@@ -76,22 +81,22 @@ class Poller(_BaseRepositoryObject):
             logging.debug("determining if series [{0}] should run...".format(series))
             if self.call(command):
 
-                logging.info("polling for series [{0}]...".format(series))
+                logging.debug("polling for series [{0}]...".format(series))
                 for branch in branches:
                     for changeset in self.repo.get_heads(branch):
 
                         request = rebuild
                         if not request:
-                            logging.info("checking if '{c}' ({b}) requires build...".format(c=changeset.rev, b=branch))
+                            logging.debug("checking if '{c}' ({b}) requires build...".format(c=changeset.rev, b=branch))
                             for build in self.repo.builds:
                                 if build.changeset.rev == changeset.rev:
-                                    logging.info("already built: {0}".format(changeset.rev))
+                                    logging.debug("already built: {0}".format(changeset.rev))
                                     break
                             else:
                                 request = True
                         if request:
                             self.count += 1
-                            logging.info("requesting builds of '{0}'...".format(changeset.rev))
+                            logging.info("requesting builds of {0} in '{1}'...".format(changeset, changeset.repo))
                             for environment in self.config.environments:
                                 name = self.name(self.count, now, series, environment, changeset, branch)
                                 request = self.repo.request_build(name, series, environment,
@@ -165,12 +170,14 @@ def run(config, daemon=False, test=False):
 
     while True:
         for poller in pollers:
+            poller.sync()
             if test:
                 logging.info("testing {p}...".format(p=poller))
                 poller.test()
             else:
-                logging.info("running {p}...".format(p=poller))
+                logging.log(logging.DEBUG if daemon else logging.INFO, "running {p}...".format(p=poller))
                 poller.run()
+            poller.sync()
         if not daemon or test:
             break
 
