@@ -5,7 +5,6 @@ Unit tests for the veracity package.
 """
 
 import os
-from random import randrange
 import logging
 from pprint import pformat
 
@@ -18,12 +17,11 @@ TEST = os.path.dirname(os.path.abspath(__file__))
 FILES = os.path.join(TEST, 'files')
 
 TEST_REPO_NAME = 'python-veracity-test'  # repository for integration tests
-TEMP_REPO_NAME = TEST_REPO_NAME + '-temp' + str(randrange(999))
 REASON = "no test repository available"
 if settings.CREATE_TEST_REPO and TEST_REPO_NAME not in vv.repos():
     common.create_test_repo(TEST_REPO_NAME)
 if TEST_REPO_NAME in vv.repos():
-    TEST_REPO = objects.Repository(TEST_REPO_NAME)
+    TEST_REPO = objects.Repository('python-veracity-test')
 else:
     TEST_REPO = None
 
