@@ -79,7 +79,7 @@ class TestConfig(unittest.TestCase):  # pylint: disable=R0904
     def test_starts_default(self):
         """Verify default starts can be read from an empty config."""
         config = Config()
-        self.assertEqual(['Q'], config.starts)
+        self.assertEqual(['Queued'], config.starts)
 
     def test_ends(self):
         """Verify sends can be read from a config."""
