@@ -95,9 +95,10 @@ def parse(output, style=None):
 
         if 'builds' in data:
             for record in data['builds']:
-                yield record['recid'], record['csid']
+                yield record['recid'], record['csid'], record['name'], record['series'], record['environment']
         elif 'build' in data:
-            yield data['build']['recid'], data['build']['csid']
+            record = data['build']
+            yield record['recid'], record['csid'], record['name'], record['series'], record['environment']
         else:
             logging.debug("no build data: {0}".format(repr(data)))
 
